# -*- coding: utf-8 -*-

# aliyun region code to code
_zone_map = {
    "hzslot": "00",
    "hangzhou": "01",
    "shanghai": "02",
    "beijing": "03",
    "zjk": "04",
    "shenzhen": "05",
    "hongkong": "06",
    "singapore": "07",
    "jakarta": "08",
    "tokyo": "09",
    "eucentral1": "10",
    "uswest1": "11",
    "useast1": "12",
    "mumbai": "13"
}

# used to convert between Decimal and 36 base number
_codec = "0123456789abcdefghijklmnopqrstuvwxyz"


def _trans_dec_to_36(num: int):
    """
    36 base number from decimal
    :rtype: int
    """
    res = ""
    while num > 0:
        res = _codec[num % 36] + res
        num = int(num / 36)
    # extend to 8 chars
    return res.rjust(8, '0')


def _trans_36_to_dec(res: str):
    """
    Decimal from 36 base number
    :rtype: basestring
    """
    num = 0
    size = len(res)
    for i in range(0, size):
        num = _codec.find(res[i]) * pow(36, size - i - 1) + num
    return str(num).rjust(8, '0')


def job_id_to_session_id(job_id: str):
    """
    job id to session id, supported until 2070-01-01 00:00:00
    :rtype: str
    """
    job_len = len(job_id)
    job_date = job_id[1:13]
    job_date_code = int(job_date) - 197001010000
    job_atomic_id = job_id[-7:]
    job_hash = job_id[-15:-7]
    job_zone = job_id[13: job_len - 15]
    return str(job_date_code) + job_atomic_id + _zone_map[job_zone] + str(_trans_36_to_dec(job_hash))


def session_id_to_job_id(session_id: str):
    """
    session id to string job id
    :rtype: basestring
    """
    job_date_code = int(session_id[0:10]) + 197001010000
    job_atomic_id = session_id[10:17]
    job_zone = list(_zone_map.keys())[list(_zone_map.values()).index(session_id[17:19])]
    job_hash = _trans_dec_to_36(int(session_id[19:]))
    return "j" + str(job_date_code) + job_zone + job_hash + job_atomic_id

